@@ -5,8 +5,6 @@ set -o errexit
 FORCE_GENERATE="${FORCE_GENERATE}"
 HASH_PATH=/var/lib/kolla/.settings.md5sum.txt
 MANAGE_PY="/usr/bin/python3 /usr/bin/manage.py"
-PYTHON_VERSION=$(python3 --version | awk '{print $2}' | awk -F'.' '{print $1"."$2}')
-SITE_PACKAGES="/usr/lib/python${PYTHON_VERSION}/site-packages"
 
 if [[ -f /etc/openstack-dashboard/custom_local_settings ]]; then
     CUSTOM_SETTINGS_FILE="${SITE_PACKAGES}/openstack_dashboard/local/custom_local_settings.py"
@@ -80,14 +78,6 @@ function config_octavia_dashboard {
         "${SITE_PACKAGES}/openstack_dashboard/local/enabled/_1482_project_load_balancer_panel.py"
 }
 
-function config_sahara_dashboard {
-    for file in ${SITE_PACKAGES}/sahara_dashboard/enabled/_*[^__].py; do
-        config_dashboard "${ENABLE_SAHARA}" \
-            "${SITE_PACKAGES}/sahara_dashboard/enabled/${file##*/}" \
-            "${SITE_PACKAGES}/openstack_dashboard/local/enabled/${file##*/}"
-    done
-}
-
 # Regenerate the compressed javascript and css if any configuration files have
 # changed.  Use a static modification date when generating the tarball
 # so that we only trigger on content changes.
@@ -113,7 +103,6 @@ config_heat_dashboard
 config_ironic_dashboard
 config_manila_ui
 config_octavia_dashboard
-config_sahara_dashboard
 
 if settings_changed; then
     ${MANAGE_PY} collectstatic --noinput --clear
