@@ -208,7 +208,9 @@ TRIPLEO_NETWORK_CONFIG_RESOURCE = 'NetworkConfig'
 
 HOST_NETWORK = 'ctlplane'
 
-EXTERNAL_TASKS = ['external_deploy_tasks']
+# The key is different in RoleConfig than in RoleData, so we need both so they
+# are correctly found.
+EXTERNAL_TASKS = ['external_deploy_tasks', 'external_deploy_steps_tasks']
 
 ANSIBLE_ERRORS_FILE = 'ansible-errors.json'
 
@@ -220,4 +222,11 @@ EXCLUSIVE_NEUTRON_DRIVERS = ['ovn', 'openvswitch']
 
 DEFAULT_STEPS_MAX = 6
 
-PER_STEP_TASKS = ['upgrade_tasks', 'deploy_steps_tasks']
+_PER_STEP_TASK_STRICTNESS = [False for i in range(DEFAULT_STEPS_MAX)]
+
+PER_STEP_TASKS = {
+    'upgrade_tasks': _PER_STEP_TASK_STRICTNESS,
+    'deploy_steps_tasks': _PER_STEP_TASK_STRICTNESS,
+    'update_tasks': _PER_STEP_TASK_STRICTNESS,
+    'post_update_tasks': [False, False, False, False]
+}
