@@ -52,7 +52,7 @@ def init_prepare_defaults(defaults_file):
 
 DEFAULT_TEMPLATE_FILE = os.path.join(sys.prefix, 'share', 'tripleo-common',
                                      'container-images',
-                                     'overcloud_containers.yaml.j2')
+                                     'tripleo_containers.yaml.j2')
 
 DEFAULT_PREPARE_FILE = os.path.join(sys.prefix, 'share', 'tripleo-common',
                                     'container-images',
@@ -100,18 +100,11 @@ def build_service_filter(environment, roles_data):
         return None
     enabled_services = get_enabled_services(environment, roles_data)
     resource_registry = environment.get('resource_registry')
-    if not resource_registry:
-        # no way to tell which services are non-containerized, so
-        # filter by enabled services
-        return enabled_services
-
-    for service, env_path in environment.get('resource_registry', {}).items():
-        if service not in enabled_services:
-            continue
-        if env_path == 'OS::Heat::None':
-            enabled_services.remove(service)
-        if '/puppet/services' in env_path:
-            enabled_services.remove(service)
+    if resource_registry:
+        for service in enabled_services.copy():
+            env_path = resource_registry.get(service)
+            if env_path == 'OS::Heat::None':
+                enabled_services.remove(service)
 
     return enabled_services
 
@@ -187,9 +180,16 @@ def container_images_prepare_multi(environment, roles_data, dry_run=False,
         modify_role = cip_entry.get('modify_role')
         modify_vars = cip_entry.get('modify_vars')
         modify_only_with_labels = cip_entry.get('modify_only_with_labels')
+        modify_only_with_source = cip_entry.get('modify_only_with_source')
         modify_append_tag = cip_entry.get('modify_append_tag',
                                           time.strftime(
                                               '-modified-%Y%m%d%H%M%S'))
+
+        # do not use tag_from_label if a tag is specified in the set
+        tag_from_label = None
+        if not mapping_args.get('tag'):
+            tag_from_label = cip_entry.get('tag_from_label')
+
         if multi_arch and 'multi_arch' in cip_entry:
             # individual entry sets multi_arch,
             # so set global multi_arch to False
@@ -204,11 +204,12 @@ def container_images_prepare_multi(environment, roles_data, dry_run=False,
             mapping_args=mapping_args,
             output_env_file='image_params',
             output_images_file='upload_data',
-            tag_from_label=cip_entry.get('tag_from_label'),
+            tag_from_label=tag_from_label,
             append_tag=modify_append_tag,
             modify_role=modify_role,
             modify_vars=modify_vars,
             modify_only_with_labels=modify_only_with_labels,
+            modify_only_with_source=modify_only_with_source,
             mirrors=mirrors,
             registry_credentials=creds,
             multi_arch=multi_arch,
@@ -216,14 +217,13 @@ def container_images_prepare_multi(environment, roles_data, dry_run=False,
         )
         env_params.update(prepare_data['image_params'])
 
-        if push_destination or pull_source or modify_role:
+        if not dry_run and (push_destination or pull_source or modify_role):
             with tempfile.NamedTemporaryFile(mode='w') as f:
                 yaml.safe_dump({
                     'container_images': prepare_data['upload_data']
                 }, f)
                 uploader = image_uploader.ImageUploadManager(
                     [f.name],
-                    dry_run=dry_run,
                     cleanup=cleanup,
                     mirrors=mirrors,
                     registry_credentials=creds,
@@ -251,6 +251,7 @@ def container_images_prepare(template_file=DEFAULT_TEMPLATE_FILE,
                              output_images_file=None, tag_from_label=None,
                              append_tag=None, modify_role=None,
                              modify_vars=None, modify_only_with_labels=None,
+                             modify_only_with_source=None,
                              mirrors=None, registry_credentials=None,
                              multi_arch=False, lock=None):
     """Perform container image preparation
@@ -278,6 +279,9 @@ def container_images_prepare(template_file=DEFAULT_TEMPLATE_FILE,
     :param modify_vars: dict of variables to pass to modify_role
     :param modify_only_with_labels: only modify the container images with the
                                     given labels
+    :param modify_only_with_source: only modify the container images from a
+                                    image_source in the tripleo-common service
+                                    to container mapping (e.g. kolla/tripleo)
     :param mirrors: dict of registry netloc values to mirror urls
     :param registry_credentials: dict of registry netloc values to
                                  authentication credentials for that registry.
@@ -343,18 +347,27 @@ def container_images_prepare(template_file=DEFAULT_TEMPLATE_FILE,
                 entry['imagename'] = '%s:%s' % (
                     image_no_tag, image_version_tags[image_no_tag])
 
+    images_with_labels = []
     if modify_only_with_labels:
         images_with_labels = uploader.filter_images_with_labels(
             images, modify_only_with_labels)
 
+    images_with_source = []
+    if modify_only_with_source:
+        images_with_source = [i.get('imagename') for i in result
+                              if i.get('image_source', '')
+                              in modify_only_with_source]
+
     params = {}
     modify_append_tag = append_tag
     for entry in result:
         imagename = entry.get('imagename', '')
         append_tag = ''
         if modify_role and (
-                (not modify_only_with_labels) or
-                imagename in images_with_labels):
+                (not modify_only_with_labels
+                    and not modify_only_with_source) or
+                (imagename in images_with_labels or
+                    imagename in images_with_source)):
             entry['modify_role'] = modify_role
             if modify_append_tag:
                 entry['modify_append_tag'] = modify_append_tag
