@@ -17,6 +17,7 @@
 import copy
 from concurrent import futures
 from concurrent.futures import ThreadPoolExecutor as tpe
+import pathlib
 from unittest import mock
 
 from tripleo_common.image.builder.buildah import BuildahBuilder as bb
@@ -36,6 +37,39 @@ BUILD_ALL_DICT_CONTAINERS = {
 }
 BUILD_ALL_STR_CONTAINER = 'container1'
 
+PREPROCESSED_CONTAINER_DEPS = [
+    {
+        "image0": [
+            "image1",
+            {
+                "image2": [
+                    {
+                        "image3": [
+                            "image4",
+                            "image5"
+                        ]
+                    },
+                    "image8",
+                    {
+                        "image6": [
+                            "image7"
+                        ]
+                    },
+                    "image9"
+                ]
+            },
+            {
+                "image10": [
+                    "image11",
+                    "image12"
+                ]
+            },
+            "image13",
+            "image14"
+        ]
+    }
+]
+
 
 class ThreadPoolExecutorReturn(object):
     _exception = None
@@ -70,14 +104,16 @@ R_BROKEN = (set(R_BROKEN_LISTS[0]), set(R_BROKEN_LISTS[1]))
 class TestBuildahBuilder(base.TestCase):
 
     @mock.patch.object(process, 'execute', autospec=True)
-    def test_build(self, mock_process):
+    @mock.patch.object(pathlib.Path, 'touch', autospec=True)
+    def test_build(self, mock_touch, mock_process):
         args = copy.copy(BUILDAH_CMD_BASE)
         dest = '127.0.0.1:8787/master/fedora-binary-fedora-base:latest'
         container_build_path = WORK_DIR + '/' + 'fedora-base'
         logfile = '/tmp/kolla/fedora-base/fedora-base-build.log'
         buildah_cmd_build = ['bud', '--format', 'docker',
-                             '--tls-verify=False', '--logfile',
-                             logfile, '-t', dest, container_build_path]
+                             '--tls-verify=False', '--layers',
+                             '--logfile', logfile, '-t',
+                             dest, container_build_path]
         args.extend(buildah_cmd_build)
         bb(WORK_DIR, DEPS).build('fedora-base', container_build_path)
         mock_process.assert_called_once_with(
@@ -88,14 +124,16 @@ class TestBuildahBuilder(base.TestCase):
         )
 
     @mock.patch.object(process, 'execute', autospec=True)
-    def test_build_without_img_type(self, mock_process):
+    @mock.patch.object(pathlib.Path, 'touch', autospec=True)
+    def test_build_without_img_type(self, mock_touch, mock_process):
         args = copy.copy(BUILDAH_CMD_BASE)
         dest = '127.0.0.1:8787/master/fedora-fedora-base:latest'
         container_build_path = WORK_DIR + '/' + 'fedora-base'
         logfile = '/tmp/kolla/fedora-base/fedora-base-build.log'
         buildah_cmd_build = ['bud', '--format', 'docker',
-                             '--tls-verify=False', '--logfile',
-                             logfile, '-t', dest, container_build_path]
+                             '--tls-verify=False', '--layers',
+                             '--logfile', logfile, '-t', dest,
+                             container_build_path]
         args.extend(buildah_cmd_build)
         bb(WORK_DIR, DEPS, img_type=False).build('fedora-base',
                                                  container_build_path)
@@ -107,7 +145,8 @@ class TestBuildahBuilder(base.TestCase):
         )
 
     @mock.patch.object(process, 'execute', autospec=True)
-    def test_build_with_volumes(self, mock_process):
+    @mock.patch.object(pathlib.Path, 'touch', autospec=True)
+    def test_build_with_volumes(self, mock_touch, mock_process):
         args = copy.copy(BUILDAH_CMD_BASE)
         dest = '127.0.0.1:8787/master/fedora-binary-fedora-base:latest'
         container_build_path = WORK_DIR + '/' + 'fedora-base'
@@ -115,8 +154,9 @@ class TestBuildahBuilder(base.TestCase):
         buildah_cmd_build = ['bud', '--volume', '/etc/pki:/etc/pki',
                              '--volume', '/etc/dir2:/dir2',
                              '--format', 'docker',
-                             '--tls-verify=False', '--logfile',
-                             logfile, '-t', dest, container_build_path]
+                             '--tls-verify=False', '--layers',
+                             '--logfile', logfile, '-t', dest,
+                             container_build_path]
         args.extend(buildah_cmd_build)
         bb(WORK_DIR, DEPS, volumes=VOLS).build('fedora-base',
                                                container_build_path)
@@ -204,11 +244,61 @@ class TestBuildahBuilder(base.TestCase):
     @mock.patch.object(tpe, 'submit', autospec=True)
     @mock.patch.object(futures, 'wait', autospec=True, return_value=R_OK)
     @mock.patch.object(process, 'execute', autospec=True)
-    def test_build_all_dict_ok(self, mock_build, mock_wait, mock_submit):
+    @mock.patch.object(pathlib.Path, 'touch', autospec=True)
+    def test_build_all_dict_ok(self, mock_touch,
+                               mock_build, mock_wait, mock_submit):
         bb(WORK_DIR, DEPS).build_all(deps=BUILD_ALL_DICT_CONTAINERS)
 
     @mock.patch.object(tpe, 'submit', autospec=True)
     @mock.patch.object(futures, 'wait', autospec=True, return_value=R_OK)
     @mock.patch.object(process, 'execute', autospec=True)
-    def test_build_all_str_ok(self, mock_build, mock_wait, mock_submit):
+    @mock.patch.object(pathlib.Path, 'touch', autospec=True)
+    def test_build_all_str_ok(self, mock_touch,
+                              mock_build, mock_wait, mock_submit):
         bb(WORK_DIR, DEPS).build_all(deps=BUILD_ALL_STR_CONTAINER)
+
+    def test_dep_processing(self):
+        containers = list()
+        self.assertEqual(
+            bb(WORK_DIR, DEPS)._generate_deps(
+                deps=PREPROCESSED_CONTAINER_DEPS,
+                containers=containers
+            ),
+            [
+                [
+                    'image0'
+                ],
+                [
+                    'image1',
+                    'image13',
+                    'image14',
+                    'image2',
+                    'image10'
+                ],
+                [
+                    'image8',
+                    'image9',
+                    'image3',
+                    'image6'
+                ],
+                [
+                    'image4',
+                    'image5'
+                ],
+                [
+                    'image7'
+                ],
+                [
+                    'image11',
+                    'image12'
+                ]
+            ]
+        )
+
+    @mock.patch(
+        'tripleo_common.image.builder.buildah.BuildahBuilder._multi_build',
+        autospec=True
+    )
+    def test_build_all_multi_build(self, mock_multi_build):
+        bb(WORK_DIR, DEPS).build_all(deps=BUILD_ALL_LIST_CONTAINERS)
+        self.assertTrue(mock_multi_build.called)
