@@ -29,7 +29,7 @@ from tripleo_common.tests import base
 
 TEMPLATE_PATH = os.path.join(os.path.dirname(__file__),
                              '..', '..', '..', 'container-images',
-                             'overcloud_containers.yaml.j2')
+                             'tripleo_containers.yaml.j2')
 
 
 DEFAULTS_PATH = os.path.join(os.path.dirname(__file__),
@@ -358,15 +358,15 @@ class TestKollaImageBuilderTemplate(base.TestCase):
     def _test_container_images_yaml_in_sync_helper(self, neutron_driver=None,
                                                    rhel_containers=False,
                                                    remove_images=[]):
-        '''Confirm overcloud_containers.tpl.yaml equals overcloud_containers.yaml
+        '''Confirm overcloud_containers.tpl.yaml equals tripleo_containers.yaml
 
-        TODO(sbaker) remove when overcloud_containers.yaml is deleted
+        TODO(sbaker) remove when tripleo_containers.yaml is deleted
         '''
         mod_dir = os.path.dirname(sys.modules[__name__].__file__)
         project_dir = os.path.abspath(os.path.join(mod_dir, '../../../'))
         files_dir = os.path.join(project_dir, 'container-images')
 
-        oc_tmpl_file = os.path.join(files_dir, 'overcloud_containers.yaml.j2')
+        oc_tmpl_file = os.path.join(files_dir, 'tripleo_containers.yaml.j2')
         tmpl_builder = kb.KollaImageBuilder([oc_tmpl_file])
 
         def ffunc(entry):
@@ -380,12 +380,12 @@ class TestKollaImageBuilderTemplate(base.TestCase):
             filter=ffunc, neutron_driver=neutron_driver,
             rhel_containers=rhel_containers)
 
-        oc_yaml_file = os.path.join(files_dir, 'overcloud_containers.yaml')
+        oc_yaml_file = os.path.join(files_dir, 'tripleo_containers.yaml')
         yaml_builder = kb.KollaImageBuilder([oc_yaml_file])
         container_images = yaml_builder.load_config_files(
             yaml_builder.CONTAINER_IMAGES)
 
-        # remove image references from overcloud_containers.yaml specified
+        # remove image references from tripleo_containers.yaml specified
         # in remove_images param.
         for image in remove_images:
             container_images.remove(image)
@@ -394,26 +394,26 @@ class TestKollaImageBuilderTemplate(base.TestCase):
 
     def test_container_images_yaml_in_sync(self):
         remove_images = [
-            {'image_source': 'kolla',
+            {'image_source': 'tripleo',
                 'imagename': KB_DEFAULT_NAMESPACE + '/' + KB_DEFAULT_PREFIX +
                              'ovn-northd:' + KB_DEFAULT_TAG},
-            {'image_source': 'kolla',
+            {'image_source': 'tripleo',
                 'imagename': KB_DEFAULT_NAMESPACE + '/' + KB_DEFAULT_PREFIX +
                              'ovn-controller:' + KB_DEFAULT_TAG},
-            {'image_source': 'kolla',
+            {'image_source': 'tripleo',
                 'imagename': KB_DEFAULT_NAMESPACE + '/' + KB_DEFAULT_PREFIX +
                              'ovn-nb-db-server:' + KB_DEFAULT_TAG},
-            {'image_source': 'kolla',
+            {'image_source': 'tripleo',
                 'imagename': KB_DEFAULT_NAMESPACE + '/' + KB_DEFAULT_PREFIX +
                              'ovn-sb-db-server:' + KB_DEFAULT_TAG},
-            {'image_source': 'kolla',
+            {'image_source': 'tripleo',
                 'imagename': KB_DEFAULT_NAMESPACE + '/' + KB_DEFAULT_PREFIX +
                              'neutron-metadata-agent-ovn:' + KB_DEFAULT_TAG}]
         self._test_container_images_yaml_in_sync_helper(
             remove_images=remove_images)
 
     def test_container_images_yaml_in_sync_for_ovn(self):
-        # remove neutron-server image reference from overcloud_containers.yaml
+        # remove neutron-server image reference from tripleo_containers.yaml
         remove_images = []
         self._test_container_images_yaml_in_sync_helper(
             neutron_driver='ovn', remove_images=remove_images)
@@ -472,7 +472,7 @@ class TestPrepare(base.TestCase):
     def test_prepare_simple(self, mock_insecure):
         self.assertEqual({
             'container_images.yaml': [
-                {'image_source': 'kolla',
+                {'image_source': 'tripleo',
                  'imagename': '192.0.2.0:8787/t/p-nova-compute:l'}
             ],
             'environments/containers-default-parameters.yaml': {
@@ -501,7 +501,7 @@ class TestPrepare(base.TestCase):
     def test_prepare_includes(self, mock_insecure):
         self.assertEqual({
             'container_images.yaml': [
-                {'image_source': 'kolla',
+                {'image_source': 'tripleo',
                  'imagename': '192.0.2.0:8787/t/p-nova-libvirt:l'}
             ],
             'environments/containers-default-parameters.yaml': {
@@ -528,7 +528,7 @@ class TestPrepare(base.TestCase):
         # assert same result as includes only. includes trumps excludes
         self.assertEqual({
             'container_images.yaml': [
-                {'image_source': 'kolla',
+                {'image_source': 'tripleo',
                  'imagename': '192.0.2.0:8787/t/p-nova-libvirt:l'}
             ],
             'environments/containers-default-parameters.yaml': {
@@ -555,7 +555,7 @@ class TestPrepare(base.TestCase):
     def test_prepare_push_dest(self, mock_insecure):
         self.assertEqual({
             'container_images.yaml': [{
-                'image_source': 'kolla',
+                'image_source': 'tripleo',
                 'imagename': 'docker.io/t/p-nova-api:l',
                 'push_destination': '192.0.2.0:8787',
             }],
@@ -591,7 +591,7 @@ class TestPrepare(base.TestCase):
         mock_gur.return_value = '192.0.2.0:8787'
         self.assertEqual({
             'container_images.yaml': [{
-                'image_source': 'kolla',
+                'image_source': 'tripleo',
                 'imagename': 'docker.io/t/p-nova-api:l',
                 'push_destination': '192.0.2.0:8787',
             }],
@@ -649,7 +649,7 @@ class TestPrepare(base.TestCase):
     def test_prepare_neutron_driver_default(self, mock_insecure):
         self.assertEqual({
             'container_images.yaml': [
-                {'image_source': 'kolla',
+                {'image_source': 'tripleo',
                  'imagename': 't/p-neutron-server:l'}
             ],
             'environments/containers-default-parameters.yaml': {
@@ -678,9 +678,9 @@ class TestPrepare(base.TestCase):
     def test_prepare_neutron_driver_ovn(self, mock_insecure):
         self.assertEqual({
             'container_images.yaml': [
-                {'image_source': 'kolla',
+                {'image_source': 'tripleo',
                  'imagename': 't/p-neutron-server:l'},
-                {'image_source': 'kolla',
+                {'image_source': 'tripleo',
                  'imagename': 't/p-ovn-controller:l'}
             ],
             'environments/containers-default-parameters.yaml': {
@@ -791,12 +791,11 @@ class TestPrepare(base.TestCase):
                 'OS::TripleO::Services::HeatApi',
                 'OS::TripleO::Services::NovaApi',
                 'OS::TripleO::Services::NovaCompute',
+                'OS::TripleO::Services::NeutronApi',
                 'OS::TripleO::Services::Kubernetes::Worker',
             ]),
             kb.build_service_filter({
                 'resource_registry': {
-                    'OS::TripleO::Services::NeutronApi':
-                    '/tht/puppet/services/foo.yaml',
                     'OS::TripleO::Services::NovaApi':
                     '/tht/docker/services/foo.yaml',
                     'OS::TripleO::Services::NovaCompute':
@@ -842,7 +841,6 @@ class TestPrepare(base.TestCase):
             'namespace': 't',
             'name_prefix': '',
             'name_suffix': '',
-            'tag': 'l',
         }
         env = {
             'parameter_defaults': {
@@ -863,6 +861,15 @@ class TestPrepare(base.TestCase):
                     'modify_role': 'add-foo-plugin',
                     'modify_only_with_labels': ['kolla_version'],
                     'modify_vars': {'foo_version': '1.0.1'}
+                }, {
+                    'set': mapping_args,
+                    'tag_from_label': 'bar',
+                    'includes': ['nova', 'neutron'],
+                    'push_destination': True,
+                    'modify_role': 'add-foo-plugin',
+                    'modify_only_with_source': ['kolla', 'tripleo'],
+                    'modify_vars': {'foo_version': '1.0.1'}
+
                 }]
             }
         }
@@ -889,6 +896,19 @@ class TestPrepare(base.TestCase):
                     'push_destination': '192.0.2.1:8787'
                 }]
             },
+            {
+                'image_params': {
+                    'BarImage': 't/bar:1.0',
+                    'BazImage': 't/baz:1.0'
+                },
+                'upload_data': [{
+                    'imagename': 't/bar:1.0',
+                    'push_destination': '192.0.2.1:8787'
+                }, {
+                    'imagename': 't/baz:1.0',
+                    'push_destination': '192.0.2.1:8787'
+                }]
+            },
         ]
 
         image_params = kb.container_images_prepare_multi(env, roles_data,
@@ -908,6 +928,7 @@ class TestPrepare(base.TestCase):
                 append_tag=mock.ANY,
                 modify_role=None,
                 modify_only_with_labels=None,
+                modify_only_with_source=None,
                 modify_vars=None,
                 mirrors={
                     'docker.io': 'http://192.0.2.2/reg/'
@@ -931,6 +952,31 @@ class TestPrepare(base.TestCase):
                 append_tag=mock.ANY,
                 modify_role='add-foo-plugin',
                 modify_only_with_labels=['kolla_version'],
+                modify_only_with_source=None,
+                modify_vars={'foo_version': '1.0.1'},
+                mirrors={
+                    'docker.io': 'http://192.0.2.2/reg/'
+                },
+                registry_credentials={
+                    'docker.io': {'my_username': 'my_password'}
+                },
+                multi_arch=False,
+                lock=mock_lock
+            ),
+            mock.call(
+                excludes=None,
+                includes=['nova', 'neutron'],
+                mapping_args=mapping_args,
+                output_env_file='image_params',
+                output_images_file='upload_data',
+                pull_source=None,
+                push_destination='192.0.2.1:8787',
+                service_filter=None,
+                tag_from_label='bar',
+                append_tag=mock.ANY,
+                modify_role='add-foo-plugin',
+                modify_only_with_labels=None,
+                modify_only_with_source=['kolla', 'tripleo'],
                 modify_vars={'foo_version': '1.0.1'},
                 mirrors={
                     'docker.io': 'http://192.0.2.2/reg/'
@@ -943,7 +989,7 @@ class TestPrepare(base.TestCase):
             )
         ])
 
-        mock_im.assert_called_once()
+        self.assertEqual(mock_im.call_count, 2)
 
         self.assertEqual(
             {
@@ -956,15 +1002,12 @@ class TestPrepare(base.TestCase):
         )
 
     @mock.patch('tripleo_common.image.kolla_builder.container_images_prepare')
-    @mock.patch('tripleo_common.image.image_uploader.ImageUploadManager',
-                autospec=True)
-    def test_container_images_prepare_multi_dry_run(self, mock_im, mock_cip):
+    def test_container_images_prepare_multi_dry_run(self, mock_cip):
         mock_lock = mock.MagicMock()
         mapping_args = {
             'namespace': 't',
             'name_prefix': '',
             'name_suffix': '',
-            'tag': 'l',
         }
         env = {
             'parameter_defaults': {
@@ -1025,6 +1068,7 @@ class TestPrepare(base.TestCase):
                 append_tag=mock.ANY,
                 modify_role=None,
                 modify_only_with_labels=None,
+                modify_only_with_source=None,
                 modify_vars=None,
                 mirrors={},
                 registry_credentials=None,
@@ -1044,6 +1088,7 @@ class TestPrepare(base.TestCase):
                 append_tag=mock.ANY,
                 modify_role='add-foo-plugin',
                 modify_only_with_labels=['kolla_version'],
+                modify_only_with_source=None,
                 modify_vars={'foo_version': '1.0.1'},
                 mirrors={},
                 registry_credentials=None,
@@ -1051,10 +1096,117 @@ class TestPrepare(base.TestCase):
                 lock=mock_lock
             )
         ])
+        self.assertEqual(
+            {
+                'BarImage': 't/bar:1.0',
+                'BazImage': 't/baz:1.0',
+                'BinkImage': 't/bink:latest',
+                'FooImage': 't/foo:latest'
+            },
+            image_params
+        )
 
-        mock_im.assert_called_once_with(mock.ANY, dry_run=True, cleanup='full',
-                                        mirrors={}, registry_credentials=None,
-                                        multi_arch=False, lock=mock_lock)
+    @mock.patch('tripleo_common.image.kolla_builder.container_images_prepare')
+    def test_container_images_prepare_multi_tag_from_label(self, mock_cip):
+        mock_lock = mock.MagicMock()
+        mapping_args = {
+            'namespace': 't',
+            'name_prefix': '',
+            'name_suffix': '',
+            'tag': 'l',
+        }
+        mapping_args_no_tag = {
+            'namespace': 't',
+            'name_prefix': '',
+            'name_suffix': '',
+        }
+        env = {
+            'parameter_defaults': {
+                'ContainerImagePrepare': [{
+                    'set': mapping_args_no_tag,
+                    'tag_from_label': 'foo',
+                }, {
+                    'set': mapping_args,
+                    'tag_from_label': 'bar',
+                    'excludes': ['nova', 'neutron'],
+                    'push_destination': '192.0.2.1:8787',
+                    'modify_role': 'add-foo-plugin',
+                    'modify_only_with_labels': ['kolla_version'],
+                    'modify_vars': {'foo_version': '1.0.1'},
+                    'modify_append_tag': 'modify-123'
+                }]
+            }
+        }
+        roles_data = []
+        mock_cip.side_effect = [
+            {
+                'image_params': {
+                    'FooImage': 't/foo:latest',
+                    'BarImage': 't/bar:latest',
+                    'BazImage': 't/baz:latest',
+                    'BinkImage': 't/bink:latest'
+                },
+                'upload_data': []
+            }, {
+                'image_params': {
+                    'BarImage': 't/bar:1.0',
+                    'BazImage': 't/baz:1.0'
+                },
+                'upload_data': [{
+                    'imagename': 't/bar:1.0',
+                    'push_destination': '192.0.2.1:8787'
+                }, {
+                    'imagename': 't/baz:1.0',
+                    'push_destination': '192.0.2.1:8787'
+                }]
+            },
+        ]
+
+        image_params = kb.container_images_prepare_multi(env, roles_data, True,
+                                                         lock=mock_lock)
+
+        mock_cip.assert_has_calls([
+            mock.call(
+                excludes=None,
+                includes=None,
+                mapping_args=mapping_args_no_tag,
+                output_env_file='image_params',
+                output_images_file='upload_data',
+                pull_source=None,
+                push_destination=None,
+                service_filter=None,
+                tag_from_label='foo',
+                append_tag=mock.ANY,
+                modify_role=None,
+                modify_only_with_labels=None,
+                modify_only_with_source=None,
+                modify_vars=None,
+                mirrors={},
+                registry_credentials=None,
+                multi_arch=False,
+                lock=mock_lock
+            ),
+            mock.call(
+                excludes=['nova', 'neutron'],
+                includes=None,
+                mapping_args=mapping_args,
+                output_env_file='image_params',
+                output_images_file='upload_data',
+                pull_source=None,
+                push_destination='192.0.2.1:8787',
+                service_filter=None,
+                tag_from_label=None,
+                append_tag=mock.ANY,
+                modify_role='add-foo-plugin',
+                modify_only_with_labels=['kolla_version'],
+                modify_only_with_source=None,
+                modify_vars={'foo_version': '1.0.1'},
+                mirrors={},
+                registry_credentials=None,
+                multi_arch=False,
+                lock=mock_lock
+            )
+        ])
 
         self.assertEqual(
             {
