@@ -24,7 +24,6 @@ import warnings
 import yaml
 
 import jinja2
-from oslo_utils import uuidutils
 from swiftclient import exceptions as swiftexceptions
 
 from tripleo_common import constants
@@ -34,8 +33,7 @@ from tripleo_common.utils import tarball
 
 LOG = logging.getLogger(__name__)
 
-warnings.filterwarnings('once', category=DeprecationWarning)
-warnings.filterwarnings('once', category=UserWarning)
+warnings.filterwarnings('once')
 
 
 class Config(object):
@@ -229,12 +227,6 @@ class Config(object):
         network_config = self.get_network_config_data(stack)
         for server, config in network_config.items():
             if server in server_roles:
-                if config is None or not uuidutils.is_uuid_like(config):
-                    # config should be a valid heat resource id
-                    err_msg = ('Invalid network config for role %s. Please '
-                               'check the network config templates used.' %
-                               server_roles[server])
-                    raise ValueError(err_msg)
                 server_deployment_dir = os.path.join(
                     config_dir, server_roles[server], server)
                 self._mkdir(server_deployment_dir)
@@ -287,9 +279,8 @@ class Config(object):
                             filepath = os.path.join(role_path, '%s_step%s.yaml'
                                                     % (config, i))
                             self._write_tasks_per_step(
-                                role[config],
-                                filepath,
-                                i, constants.PER_STEP_TASKS[config][i])
+                                role[config], filepath, i,
+                                constants.PER_STEP_TASKS[config][i])
 
                     try:
                         data = role[config]
@@ -443,9 +434,6 @@ class Config(object):
                 raise Exception(err_msg)
 
             role = self.get_role_from_server_id(stack, server_id)
-            server_pre_network = server_deployment_names.setdefault(
-                server_names[server_id], {}).setdefault(
-                'pre_network', [])
             server_pre_deployments = server_deployment_names.setdefault(
                 server_names[server_id], {}).setdefault(
                 'pre_deployments', [])
@@ -463,9 +451,6 @@ class Config(object):
                     'PostConfig' in deployment.physical_resource_id:
                 if deployment_name not in server_post_deployments:
                     server_post_deployments.append(deployment_name)
-            elif 'PreNetworkConfig' in deployment.physical_resource_id:
-                if deployment_name not in server_pre_network:
-                    server_pre_network.append(deployment_name)
             else:
                 if deployment_name not in server_pre_deployments:
                     server_pre_deployments.append(deployment_name)
@@ -558,8 +543,6 @@ class Config(object):
                     role_host_vars[role][server],
                     default_flow_style=False) if role_host_vars else None)
 
-            pre_network = server_deployment_names.get(
-                server, {}).get('pre_network', [])
             pre_deployments = server_deployment_names.get(
                 server, {}).get('pre_deployments', [])
             post_deployments = server_deployment_names.get(
@@ -568,7 +551,6 @@ class Config(object):
             with open(host_var_server_path, 'w') as f:
                 template_data = host_var_server_template.render(
                     role=role,
-                    pre_network=pre_network,
                     pre_deployments=pre_deployments,
                     post_deployments=post_deployments,
                     ansible_host_vars=ansible_host_vars)
