@@ -19,6 +19,7 @@ import re
 from oslo_utils import netutils
 import six
 
+from ironicclient import exceptions as ironicexceptions
 from oslo_concurrency import processutils
 from tripleo_common import exception
 from tripleo_common.utils import glance
@@ -266,34 +267,34 @@ class iBootDriverInfo(PrefixedDriverInfo):
 
 DRIVER_INFO = {
     # production drivers
-    '(ipmi|.*_ipmitool)': PrefixedDriverInfo('ipmi', has_port=True,
-                                             default_port=623,
-                                             hardware_type='ipmi',
-                                             mandatory_fields=['pm_addr']
-                                             ),
-    '(idrac|.*_drac)': PrefixedDriverInfo('drac', has_port=True,
-                                          hardware_type='idrac'),
-    '(ilo|.*_ilo)': PrefixedDriverInfo('ilo', has_port=True,
-                                       hardware_type='ilo'),
-    '(irmc|.*_irmc)': PrefixedDriverInfo('irmc', has_port=True,
-                                         hardware_type='irmc'),
-    'redfish': RedfishDriverInfo(),
-    'xclarity': PrefixedDriverInfo('xclarity', has_port=True),
+    r'^(ipmi|.*_ipmitool)$': PrefixedDriverInfo('ipmi', has_port=True,
+                                                default_port=623,
+                                                hardware_type='ipmi',
+                                                mandatory_fields=['pm_addr']
+                                                ),
+    r'^(idrac|.*_drac)$': PrefixedDriverInfo('drac', has_port=True,
+                                             hardware_type='idrac'),
+    r'^(ilo|.*_ilo)$': PrefixedDriverInfo('ilo', has_port=True,
+                                          hardware_type='ilo'),
+    r'^(irmc|.*_irmc)$': PrefixedDriverInfo('irmc', has_port=True,
+                                            hardware_type='irmc'),
+    r'^redfish$': RedfishDriverInfo(),
+    r'^xclarity$': PrefixedDriverInfo('xclarity', has_port=True),
     # test drivers
-    r'staging\-ovirt': oVirtDriverInfo(),
-    r'(staging\-iboot|.*_iboot)': iBootDriverInfo(),
-    r'(staging\-wol|.*wol)': DriverInfo(
+    r'^staging\-ovirt$': oVirtDriverInfo(),
+    r'^(staging\-iboot|.*_iboot)$': iBootDriverInfo(),
+    r'^(staging\-wol|.*wol)$': DriverInfo(
         'wol',
         mapping={
             'pm_addr': 'wol_host',
             'pm_port': 'wol_port',
         },
         hardware_type='staging-wol'),
-    r'(staging\-amt|.*_amt)': PrefixedDriverInfo('amt',
-                                                 hardware_type='staging-amt'),
+    r'^(staging\-amt|.*_amt)$': PrefixedDriverInfo(
+        'amt', hardware_type='staging-amt'),
     # fake_pxe was used when no management interface was supported, now
     # manual-management is used for the same purpose
-    r'(manual\-management|fake_pxe|fake_agent)': DriverInfo(
+    r'^(manual\-management|fake_pxe|fake_agent)$': DriverInfo(
         'fake', mapping={}, hardware_type='manual-management'),
     r'^fake(|\-hardware)$': DriverInfo('fake', mapping={},
                                        hardware_type='fake-hardware'),
@@ -302,7 +303,7 @@ DRIVER_INFO = {
 
 def find_driver_handler(driver):
     for driver_tpl, handler in DRIVER_INFO.items():
-        if re.match(driver_tpl, driver) is not None:
+        if re.search(driver_tpl, driver) is not None:
             return handler
 
     # FIXME(dtantsur): handle all drivers without hardcoding them
@@ -708,10 +709,16 @@ def generate_hostmap(baremetal_client, compute_client):
     """Create a map between Compute nodes and Baremetal nodes"""
     hostmap = {}
     for node in compute_client.servers.list():
-        bm_node = baremetal_client.node.get_by_instance_uuid(node.id)
-        for port in baremetal_client.port.list(node=bm_node.uuid):
-            hostmap[port.address] = {"compute_name": node.name,
-                                     "baremetal_name": bm_node.name}
+        try:
+            bm_node = baremetal_client.node.get_by_instance_uuid(node.id)
+            for port in baremetal_client.port.list(node=bm_node.uuid):
+                hostmap[port.address] = {"compute_name": node.name,
+                                         "baremetal_name": bm_node.name}
+        except ironicexceptions.NotFound:
+            LOG.warning('Baremetal node for server %s not found - skipping it',
+                        node.id)
+            pass
+
     if hostmap == {}:
         return None
     else:
